public struct Point
{
    public int X, Y;
    public Point(int x, int y)
    {
        X = x;
        Y = y;
    }
}
static void Main(string[] args)
{
    int N = int.Parse(Console.ReadLine());
    var tacke = new List<Point>();

    for (int i = 0; i < N; i++)
    {
        var unos = Console.ReadLine().Split();
        tacke.Add(new Point(int.Parse(unos[0]), int.Parse(unos[1])));
    }

    long minPov = long.MaxValue;

    for (int i = 0; i < N; i++)
    {
        var reducedPoints = tacke.Where((_, index) => index != i).ToList();

        var hull = ConvexHull(reducedPoints);

        long area = PolygonArea(hull);
        minPov = Math.Min(minPov, area);
    }

    Console.WriteLine(minPov);
}

static List<Point> ConvexHull(List<Point> points)
{
    points = points.OrderBy(p => p.X).ThenBy(p => p.Y).ToList();

    var telo = new List<Point>();

    foreach (var p in points)
    {
        while (telo.Count >= 2 && Cross(telo[telo.Count - 2], telo[telo.Count - 1], p) <= 0)
            telo.RemoveAt(telo.Count - 1);
        telo.Add(p);
    }

    int lowerCount = telo.Count;
    for (int i = points.Count - 2; i >= 0; i--)
    {
        while (telo.Count > lowerCount && Cross(telo[telo.Count - 2], telo[telo.Count - 1], points[i]) <= 0)
            telo.RemoveAt(telo.Count - 1);
        telo.Add(points[i]);
    }

    telo.RemoveAt(telo.Count - 1); 
    return telo;
}

static long Cross(Point a, Point b, Point c)
{
    return (long)(b.X - a.X) * (c.Y - a.Y) - (long)(b.Y - a.Y) * (c.X - a.X);
}

static long PolygonArea(List<Point> points)
{
    long Pov = 0;
    int n = points.Count;

    for (int i = 0; i < n; i++)
    {
        int j = (i + 1) % n;
        Pov += (long)points[i].X * points[j].Y - (long)points[j].X * points[i].Y;
    }

    return Math.Abs(Pov) / 2;
}